@@ -1,8 +1,10 @@
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include "lookup.h"
 
-static
-struct	hashlist *hashtab[HASHMAX];
+static struct	hashlist *hashtab[HASHMAX];
+static char *strsave(char *s);
 
 /*
  * from K&R "The C Programming language"
@@ -11,8 +13,7 @@ struct	hashlist *hashtab[HASHMAX];
  * hash - for a hash value for string s
  *
  */
-hash(s)
-S_CHAR *s;
+int hash(char *s)
 {
 	int	hashval;
 
@@ -25,9 +26,7 @@ S_CHAR *s;
  * lookup - lookup for a string s in the hash table
  *
  */
-struct hashlist
-*lookup(s)
-S_CHAR *s;
+struct hashlist *lookup(char *s)
 {
 	struct hashlist *np;
 
@@ -41,14 +40,10 @@ S_CHAR *s;
  * install - install a string name in hashtable and its value def
  *
  */
-struct hashlist
-*install(name,def)
-S_CHAR *name;
-S_CHAR *def;
+struct hashlist *install(char *name, char *def)
 {
 	int hashval;
 	struct hashlist *np, *lookup();
-	S_CHAR *strsave(), *malloc();
 
 	if ((np = lookup(name)) == NULL) {	/* not found.. */
 		np = (struct hashlist *) malloc(sizeof(*np));
@@ -70,11 +65,9 @@ S_CHAR *def;
  * strsave - save string s somewhere
  *
  */
-S_CHAR
-*strsave(s)
-S_CHAR *s;
+static char *strsave(char *s)
 {
-	S_CHAR *p, *malloc();
+	char *p;
 
 	if ((p = malloc(strlen(s)+1)) != NULL)
 		strcpy(p, s);
