@@ -8,11 +8,14 @@
 
 					/* basic table entry */
 struct hashlist {
-	S_CHAR	*name;
-	S_CHAR	*def;
+	char	*name;
+	char	*def;
 	struct	hashlist *next;		/* next in chain     */
 };
 
 #define HASHMAX	100			/* size of hashtable */
 
 					/* hash table itself */
+
+extern struct hashlist *lookup(char *s);
+
